@@ -22,8 +22,9 @@ module.
     See the License for the specific language governing permissions
     and limitations under the License.
 """
+from __future__ import unicode_literals
 
-__version__ = '2.3.0'
+__version__ = '3.1'
 
 __all__ = [
     'association',
